---
title: <span class="badge object-type-scalar"></span> BulgarianLev
---
# <span class="badge object-type-scalar"></span> BulgarianLev

Currency: Bulgarian Lev (BGN)

## Definition

```python
# Currency: Bulgarian Lev (BGN)
BulgarianLev: typing.Literal["currencyBGN"] = "currencyBGN"
```
